from distutils.core import setup
setup(
	name='hcl_exception.py',
	version='1.0.0',
	py_modules=['hcl_exception'],
	author='wanliguhong',
	email='huchaoling0823@126.com',
	url='http://pypi.python.org/',
	description='char data.',
	)
